# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: executor/v1/executor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65xecutor/v1/executor.proto\x12\x08\x65xecutor\x1a\x1egoogle/protobuf/duration.proto\"\x1c\n\x0c\x45xecutorInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\"U\n\nSystemInfo\x12\n\n\x02os\x18\x02 \x01(\t\x12\x0c\n\x04\x61rch\x18\x03 \x01(\t\x12\x17\n\x0ftotal_cpu_cores\x18\x04 \x01(\r\x12\x14\n\x0ctotal_memory\x18\x05 \x01(\x04\"\x13\n\x11IntrospectRequest\"{\n\x12IntrospectResponse\x12&\n\x08sys_info\x18\x01 \x01(\x0b\x32\x14.executor.SystemInfo\x12-\n\rexecutor_info\x18\x03 \x01(\x0b\x32\x16.executor.ExecutorInfo\x12\x0e\n\x06labels\x18\x02 \x03(\t\"Q\n\x0bOpenRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x12\n\nruntime_id\x18\x02 \x01(\t\x12\x1c\n\x04opts\x18\x03 \x01(\x0b\x32\x0e.executor.Opts\"N\n\x0cOpenResponse\x12\x16\n\x0ework_directory\x18\x01 \x01(\t\x12&\n\x08sys_info\x18\x02 \x01(\x0b\x32\x14.executor.SystemInfo\"&\n\x10HeartbeatRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"C\n\x11HeartbeatResponse\x12.\n\x0b\x65xtended_by\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xe4\x01\n\x04Opts\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.executor.RuntimeType\x12\x0e\n\x06labels\x18\x04 \x03(\t\x12&\n\x04tags\x18\x05 \x03(\x0b\x32\x18.executor.Opts.TagsEntry\x12\"\n\x04host\x18\x02 \x01(\x0b\x32\x12.executor.HostOptsH\x00\x12&\n\x06\x64ocker\x18\x03 \x01(\x0b\x32\x14.executor.DockerOptsH\x00\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04opts\"\n\n\x08HostOpts\"5\n\nDockerOpts\x12\'\n\x05image\x18\x01 \x01(\x0b\x32\x18.executor.DockerPullOpts\"\x89\x02\n\x0e\x44ockerPullOpts\x12\x11\n\timage_uri\x18\x01 \x01(\t\x12<\n\rpull_strategy\x18\x02 \x01(\x0e\x32%.executor.DockerPullOpts.PullStrategy\x12&\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x18.executor.DockerPullAuth\"~\n\x0cPullStrategy\x12\x1d\n\x19PULL_STRATEGY_UNSPECIFIED\x10\x00\x12\x17\n\x13PULL_STRATEGY_NEVER\x10\x01\x12\x18\n\x14PULL_STRATEGY_ALWAYS\x10\x02\x12\x1c\n\x18PULL_STRATEGY_NOT_EXISTS\x10\x03\"g\n\x0e\x44ockerPullAuth\x12$\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\x13.executor.BasicAuthH\x00\x12\'\n\x07\x61ws_ecr\x18\x02 \x01(\x0b\x32\x14.executor.AWSECRAuthH\x00\x42\x06\n\x04\x61uth\"/\n\tBasicAuth\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"O\n\nAWSECRAuth\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x19\n\x11\x61ws_access_key_id\x18\x02 \x01(\t\x12\x16\n\x0e\x61ws_secret_key\x18\x03 \x01(\t\"T\n\x0b\x45xecRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65xec_id\x18\x02 \x01(\t\x12 \n\x04opts\x18\x03 \x01(\x0b\x32\x12.executor.ExecOpts\"\x8c\x01\n\x08\x45xecOpts\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x0b\n\x03\x65nv\x18\x03 \x03(\t\x12*\n\x04tags\x18\x04 \x03(\x0b\x32\x1c.executor.ExecOpts.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x0c\x45xecResponse\x12\x11\n\texit_code\x18\x01 \x01(\x05\"\xce\x01\n\x0c\x46ileTransfer\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x03 \x01(\t\x12,\n\x06header\x18\x04 \x01(\x0b\x32\x1c.executor.FileTransferHeader\x12(\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x1a.executor.FileTransferBody\x12.\n\x07trailer\x18\x06 \x01(\x0b\x32\x1d.executor.FileTransferTrailer\"e\n\x12\x46ileTransferHeader\x12\x0e\n\x06is_dir\x18\x01 \x01(\x08\x12\x10\n\x08src_path\x18\x02 \x01(\t\x12\x11\n\tdest_path\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\r\x12\x0c\n\x04size\x18\x05 \x01(\x04\"0\n\x10\x46ileTransferBody\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\"\n\x13\x46ileTransferTrailer\x12\x0b\n\x03md5\x18\x01 \x01(\x0c\"\x10\n\x0eImportResponse\"[\n\rExportRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x11\n\texport_id\x18\x02 \x01(\t\x12\x10\n\x08src_path\x18\x03 \x01(\t\x12\x11\n\tdest_path\x18\x04 \x01(\t\"\"\n\x0c\x43loseRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"\x0f\n\rCloseResponse\"#\n\rEventsRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"\xcc\x07\n\x05\x45vent\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x41\n\x14runtime_tender_start\x18\x04 \x01(\x0b\x32!.executor.RuntimeTenderStartEventH\x00\x12=\n\x12runtime_tender_end\x18\x05 \x01(\x0b\x32\x1f.executor.RuntimeTenderEndEventH\x00\x12I\n\x18runtime_settlement_start\x18\x06 \x01(\x0b\x32%.executor.RuntimeSettlementStartEventH\x00\x12\x45\n\x16runtime_settlement_end\x18\x07 \x01(\x0b\x32#.executor.RuntimeSettlementEndEventH\x00\x12=\n\x12runtime_open_start\x18\x08 \x01(\x0b\x32\x1f.executor.RuntimeOpenStartEventH\x00\x12\x39\n\x10runtime_open_end\x18\t \x01(\x0b\x32\x1d.executor.RuntimeOpenEndEventH\x00\x12.\n\nexec_start\x18\n \x01(\x0b\x32\x18.executor.ExecStartEventH\x00\x12*\n\x08\x65xec_end\x18\x0b \x01(\x0b\x32\x16.executor.ExecEndEventH\x00\x12\x32\n\x0cimport_start\x18\x0c \x01(\x0b\x32\x1a.executor.ImportStartEventH\x00\x12.\n\nimport_end\x18\r \x01(\x0b\x32\x18.executor.ImportEndEventH\x00\x12\x32\n\x0c\x65xport_start\x18\x0e \x01(\x0b\x32\x1a.executor.ExportStartEventH\x00\x12.\n\nexport_end\x18\x0f \x01(\x0b\x32\x18.executor.ExportEndEventH\x00\x12\'\n\x06stdout\x18\x10 \x01(\x0b\x32\x15.executor.StdoutEventH\x00\x12\'\n\x06stderr\x18\x11 \x01(\x0b\x32\x15.executor.StderrEventH\x00\x12?\n\x13runtime_close_start\x18\x12 \x01(\x0b\x32 .executor.RuntimeCloseStartEventH\x00\x12;\n\x11runtime_close_end\x18\x13 \x01(\x0b\x32\x1e.executor.RuntimeCloseEndEventH\x00\x42\t\n\x07payload\"\\\n\x17RuntimeTenderStartEvent\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x11\n\ttender_id\x18\x02 \x01(\t\x12\x1c\n\x04opts\x18\x03 \x01(\x0b\x32\x0e.executor.Opts\"*\n\x15RuntimeTenderEndEvent\x12\x11\n\ttender_id\x18\x01 \x01(\t\"Y\n\x1bRuntimeSettlementStartEvent\x12\x11\n\ttender_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontract_id\x18\x02 \x01(\t\x12\x12\n\nruntime_id\x18\x03 \x01(\t\"W\n\x19RuntimeSettlementEndEvent\x12\x11\n\ttender_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontract_id\x18\x02 \x01(\t\x12\x12\n\nruntime_id\x18\x03 \x01(\t\"I\n\x15RuntimeOpenStartEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x1c\n\x04opts\x18\x02 \x01(\x0b\x32\x0e.executor.Opts\")\n\x13RuntimeOpenEndEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\",\n\x16RuntimeCloseStartEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"*\n\x14RuntimeCloseEndEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"E\n\x0bStdoutEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12(\n\x06source\x18\x02 \x01(\x0b\x32\x18.executor.LogEventSource\"E\n\x0bStderrEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12(\n\x06source\x18\x02 \x01(\x0b\x32\x18.executor.LogEventSource\"\xa3\x01\n\x0eLogEventSource\x12-\n\x07runtime\x18\x02 \x01(\x0b\x32\x1a.executor.LogSourceRuntimeH\x00\x12\'\n\x04\x65xec\x18\x03 \x01(\x0b\x32\x17.executor.LogSourceExecH\x00\x12/\n\x08\x64irector\x18\x04 \x01(\x0b\x32\x1b.executor.LogSourceDirectorH\x00\x42\x08\n\x06source\"&\n\x10LogSourceRuntime\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"D\n\rLogSourceExec\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65xec_id\x18\x02 \x01(\t\x12\x0e\n\x06system\x18\x03 \x01(\x08\"\x13\n\x11LogSourceDirector\"\xb6\x01\n\x0e\x45xecStartEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65xec_id\x18\x02 \x01(\t\x12 \n\x04opts\x18\x03 \x01(\x0b\x32\x12.executor.ExecOpts\x12\x30\n\x04tags\x18\x04 \x03(\x0b\x32\".executor.ExecStartEvent.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"9\n\x10ImportStartEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\"7\n\x0eImportEndEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\"9\n\x10\x45xportStartEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x11\n\texport_id\x18\x02 \x01(\t\"7\n\x0e\x45xportEndEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x11\n\texport_id\x18\x02 \x01(\t\"U\n\x0c\x45xecEndEvent\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65xec_id\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\x11\n\texit_code\x18\x04 \x01(\x05*L\n\x0bRuntimeType\x12\x17\n\x13RUNTIME_UNSPECIFIED\x10\x00\x12\x10\n\x0cRUNTIME_HOST\x10\x01\x12\x12\n\x0eRUNTIME_DOCKER\x10\x02\x32\xf2\x03\n\x08\x45xecutor\x12G\n\nIntrospect\x12\x1b.executor.IntrospectRequest\x1a\x1c.executor.IntrospectResponse\x12\x35\n\x04Open\x12\x15.executor.OpenRequest\x1a\x16.executor.OpenResponse\x12\x44\n\tHeartbeat\x12\x1a.executor.HeartbeatRequest\x1a\x1b.executor.HeartbeatResponse\x12\x35\n\x04\x45xec\x12\x15.executor.ExecRequest\x1a\x16.executor.ExecResponse\x12<\n\x06Import\x12\x16.executor.FileTransfer\x1a\x18.executor.ImportResponse(\x01\x12;\n\x06\x45xport\x12\x17.executor.ExportRequest\x1a\x16.executor.FileTransfer0\x01\x12\x38\n\x05\x43lose\x12\x16.executor.CloseRequest\x1a\x17.executor.CloseResponse\x12\x34\n\x06\x45vents\x12\x17.executor.EventsRequest\x1a\x0f.executor.Event0\x01\x42+Z)github.com/knita-io/knita/api/executor/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'executor.v1.executor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/knita-io/knita/api/executor/v1'
  _globals['_OPTS_TAGSENTRY']._loaded_options = None
  _globals['_OPTS_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_EXECOPTS_TAGSENTRY']._loaded_options = None
  _globals['_EXECOPTS_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_EXECSTARTEVENT_TAGSENTRY']._loaded_options = None
  _globals['_EXECSTARTEVENT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_RUNTIMETYPE']._serialized_start=4715
  _globals['_RUNTIMETYPE']._serialized_end=4791
  _globals['_EXECUTORINFO']._serialized_start=72
  _globals['_EXECUTORINFO']._serialized_end=100
  _globals['_SYSTEMINFO']._serialized_start=102
  _globals['_SYSTEMINFO']._serialized_end=187
  _globals['_INTROSPECTREQUEST']._serialized_start=189
  _globals['_INTROSPECTREQUEST']._serialized_end=208
  _globals['_INTROSPECTRESPONSE']._serialized_start=210
  _globals['_INTROSPECTRESPONSE']._serialized_end=333
  _globals['_OPENREQUEST']._serialized_start=335
  _globals['_OPENREQUEST']._serialized_end=416
  _globals['_OPENRESPONSE']._serialized_start=418
  _globals['_OPENRESPONSE']._serialized_end=496
  _globals['_HEARTBEATREQUEST']._serialized_start=498
  _globals['_HEARTBEATREQUEST']._serialized_end=536
  _globals['_HEARTBEATRESPONSE']._serialized_start=538
  _globals['_HEARTBEATRESPONSE']._serialized_end=605
  _globals['_OPTS']._serialized_start=608
  _globals['_OPTS']._serialized_end=836
  _globals['_OPTS_TAGSENTRY']._serialized_start=785
  _globals['_OPTS_TAGSENTRY']._serialized_end=828
  _globals['_HOSTOPTS']._serialized_start=838
  _globals['_HOSTOPTS']._serialized_end=848
  _globals['_DOCKEROPTS']._serialized_start=850
  _globals['_DOCKEROPTS']._serialized_end=903
  _globals['_DOCKERPULLOPTS']._serialized_start=906
  _globals['_DOCKERPULLOPTS']._serialized_end=1171
  _globals['_DOCKERPULLOPTS_PULLSTRATEGY']._serialized_start=1045
  _globals['_DOCKERPULLOPTS_PULLSTRATEGY']._serialized_end=1171
  _globals['_DOCKERPULLAUTH']._serialized_start=1173
  _globals['_DOCKERPULLAUTH']._serialized_end=1276
  _globals['_BASICAUTH']._serialized_start=1278
  _globals['_BASICAUTH']._serialized_end=1325
  _globals['_AWSECRAUTH']._serialized_start=1327
  _globals['_AWSECRAUTH']._serialized_end=1406
  _globals['_EXECREQUEST']._serialized_start=1408
  _globals['_EXECREQUEST']._serialized_end=1492
  _globals['_EXECOPTS']._serialized_start=1495
  _globals['_EXECOPTS']._serialized_end=1635
  _globals['_EXECOPTS_TAGSENTRY']._serialized_start=785
  _globals['_EXECOPTS_TAGSENTRY']._serialized_end=828
  _globals['_EXECRESPONSE']._serialized_start=1637
  _globals['_EXECRESPONSE']._serialized_end=1670
  _globals['_FILETRANSFER']._serialized_start=1673
  _globals['_FILETRANSFER']._serialized_end=1879
  _globals['_FILETRANSFERHEADER']._serialized_start=1881
  _globals['_FILETRANSFERHEADER']._serialized_end=1982
  _globals['_FILETRANSFERBODY']._serialized_start=1984
  _globals['_FILETRANSFERBODY']._serialized_end=2032
  _globals['_FILETRANSFERTRAILER']._serialized_start=2034
  _globals['_FILETRANSFERTRAILER']._serialized_end=2068
  _globals['_IMPORTRESPONSE']._serialized_start=2070
  _globals['_IMPORTRESPONSE']._serialized_end=2086
  _globals['_EXPORTREQUEST']._serialized_start=2088
  _globals['_EXPORTREQUEST']._serialized_end=2179
  _globals['_CLOSEREQUEST']._serialized_start=2181
  _globals['_CLOSEREQUEST']._serialized_end=2215
  _globals['_CLOSERESPONSE']._serialized_start=2217
  _globals['_CLOSERESPONSE']._serialized_end=2232
  _globals['_EVENTSREQUEST']._serialized_start=2234
  _globals['_EVENTSREQUEST']._serialized_end=2269
  _globals['_EVENT']._serialized_start=2272
  _globals['_EVENT']._serialized_end=3244
  _globals['_RUNTIMETENDERSTARTEVENT']._serialized_start=3246
  _globals['_RUNTIMETENDERSTARTEVENT']._serialized_end=3338
  _globals['_RUNTIMETENDERENDEVENT']._serialized_start=3340
  _globals['_RUNTIMETENDERENDEVENT']._serialized_end=3382
  _globals['_RUNTIMESETTLEMENTSTARTEVENT']._serialized_start=3384
  _globals['_RUNTIMESETTLEMENTSTARTEVENT']._serialized_end=3473
  _globals['_RUNTIMESETTLEMENTENDEVENT']._serialized_start=3475
  _globals['_RUNTIMESETTLEMENTENDEVENT']._serialized_end=3562
  _globals['_RUNTIMEOPENSTARTEVENT']._serialized_start=3564
  _globals['_RUNTIMEOPENSTARTEVENT']._serialized_end=3637
  _globals['_RUNTIMEOPENENDEVENT']._serialized_start=3639
  _globals['_RUNTIMEOPENENDEVENT']._serialized_end=3680
  _globals['_RUNTIMECLOSESTARTEVENT']._serialized_start=3682
  _globals['_RUNTIMECLOSESTARTEVENT']._serialized_end=3726
  _globals['_RUNTIMECLOSEENDEVENT']._serialized_start=3728
  _globals['_RUNTIMECLOSEENDEVENT']._serialized_end=3770
  _globals['_STDOUTEVENT']._serialized_start=3772
  _globals['_STDOUTEVENT']._serialized_end=3841
  _globals['_STDERREVENT']._serialized_start=3843
  _globals['_STDERREVENT']._serialized_end=3912
  _globals['_LOGEVENTSOURCE']._serialized_start=3915
  _globals['_LOGEVENTSOURCE']._serialized_end=4078
  _globals['_LOGSOURCERUNTIME']._serialized_start=4080
  _globals['_LOGSOURCERUNTIME']._serialized_end=4118
  _globals['_LOGSOURCEEXEC']._serialized_start=4120
  _globals['_LOGSOURCEEXEC']._serialized_end=4188
  _globals['_LOGSOURCEDIRECTOR']._serialized_start=4190
  _globals['_LOGSOURCEDIRECTOR']._serialized_end=4209
  _globals['_EXECSTARTEVENT']._serialized_start=4212
  _globals['_EXECSTARTEVENT']._serialized_end=4394
  _globals['_EXECSTARTEVENT_TAGSENTRY']._serialized_start=785
  _globals['_EXECSTARTEVENT_TAGSENTRY']._serialized_end=828
  _globals['_IMPORTSTARTEVENT']._serialized_start=4396
  _globals['_IMPORTSTARTEVENT']._serialized_end=4453
  _globals['_IMPORTENDEVENT']._serialized_start=4455
  _globals['_IMPORTENDEVENT']._serialized_end=4510
  _globals['_EXPORTSTARTEVENT']._serialized_start=4512
  _globals['_EXPORTSTARTEVENT']._serialized_end=4569
  _globals['_EXPORTENDEVENT']._serialized_start=4571
  _globals['_EXPORTENDEVENT']._serialized_end=4626
  _globals['_EXECENDEVENT']._serialized_start=4628
  _globals['_EXECENDEVENT']._serialized_end=4713
  _globals['_EXECUTOR']._serialized_start=4794
  _globals['_EXECUTOR']._serialized_end=5292
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: director/v1/director.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import executor_pb2 as executor_dot_v1_dot_executor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64irector/v1/director.proto\x12\x08\x64irector\x1a\x1a\x65xecutor/v1/executor.proto\"=\n\x0bOpenRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x1c\n\x04opts\x18\x02 \x01(\x0b\x32\x0e.executor.Opts\"b\n\x0cOpenResponse\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x16\n\x0ework_directory\x18\x02 \x01(\t\x12&\n\x08sys_info\x18\x03 \x01(\x0b\x32\x14.executor.SystemInfo\"H\n\rImportRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x10\n\x08src_path\x18\x02 \x01(\t\x12\x11\n\tdest_path\x18\x03 \x01(\t\"\x10\n\x0eImportResponse\"H\n\rExportRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\x10\n\x08src_path\x18\x02 \x01(\t\x12\x11\n\tdest_path\x18\x03 \x01(\t\"\x10\n\x0e\x45xportResponse\"\x0f\n\rEventsRequest\"C\n\x0b\x45xecRequest\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12 \n\x04opts\x18\x02 \x01(\x0b\x32\x12.executor.ExecOpts\"\xcc\x01\n\tExecEvent\x12.\n\nexec_start\x18\x04 \x01(\x0b\x32\x18.director.ExecStartEventH\x00\x12*\n\x08\x65xec_end\x18\x01 \x01(\x0b\x32\x16.director.ExecEndEventH\x00\x12+\n\x06stdout\x18\x02 \x01(\x0b\x32\x19.director.ExecStdoutEventH\x00\x12+\n\x06stderr\x18\x03 \x01(\x0b\x32\x19.director.ExecStderrEventH\x00\x42\t\n\x07payload\"\x10\n\x0e\x45xecStartEvent\"0\n\x0c\x45xecEndEvent\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x11\n\texit_code\x18\x02 \x01(\x05\"\x1f\n\x0f\x45xecStdoutEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1f\n\x0f\x45xecStderrEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x32\xab\x02\n\x08\x44irector\x12\x35\n\x04Open\x12\x15.director.OpenRequest\x1a\x16.director.OpenResponse\x12\x34\n\x04\x45xec\x12\x15.director.ExecRequest\x1a\x13.director.ExecEvent0\x01\x12;\n\x06Import\x12\x17.director.ImportRequest\x1a\x18.director.ImportResponse\x12;\n\x06\x45xport\x12\x17.director.ExportRequest\x1a\x18.director.ExportResponse\x12\x38\n\x05\x43lose\x12\x16.executor.CloseRequest\x1a\x17.executor.CloseResponseB+Z)github.com/knita-io/knita/api/director/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'director.v1.director_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/knita-io/knita/api/director/v1'
  _globals['_OPENREQUEST']._serialized_start=68
  _globals['_OPENREQUEST']._serialized_end=129
  _globals['_OPENRESPONSE']._serialized_start=131
  _globals['_OPENRESPONSE']._serialized_end=229
  _globals['_IMPORTREQUEST']._serialized_start=231
  _globals['_IMPORTREQUEST']._serialized_end=303
  _globals['_IMPORTRESPONSE']._serialized_start=305
  _globals['_IMPORTRESPONSE']._serialized_end=321
  _globals['_EXPORTREQUEST']._serialized_start=323
  _globals['_EXPORTREQUEST']._serialized_end=395
  _globals['_EXPORTRESPONSE']._serialized_start=397
  _globals['_EXPORTRESPONSE']._serialized_end=413
  _globals['_EVENTSREQUEST']._serialized_start=415
  _globals['_EVENTSREQUEST']._serialized_end=430
  _globals['_EXECREQUEST']._serialized_start=432
  _globals['_EXECREQUEST']._serialized_end=499
  _globals['_EXECEVENT']._serialized_start=502
  _globals['_EXECEVENT']._serialized_end=706
  _globals['_EXECSTARTEVENT']._serialized_start=708
  _globals['_EXECSTARTEVENT']._serialized_end=724
  _globals['_EXECENDEVENT']._serialized_start=726
  _globals['_EXECENDEVENT']._serialized_end=774
  _globals['_EXECSTDOUTEVENT']._serialized_start=776
  _globals['_EXECSTDOUTEVENT']._serialized_end=807
  _globals['_EXECSTDERREVENT']._serialized_start=809
  _globals['_EXECSTDERREVENT']._serialized_end=840
  _globals['_DIRECTOR']._serialized_start=843
  _globals['_DIRECTOR']._serialized_end=1142
# @@protoc_insertion_point(module_scope)



import os
import grpc

from . import director_pb2
from . import executor_pb2
from . import director_pb2_grpc
from . import runtime


class ConfigException(Exception):
    """Raised when an invalid configuration value is provided to Knita."""
    pass


class Client:
    """Client connects back to the Knita CLI process to orchestrate builds."""
    __build_id: str
    __director_stub: director_pb2_grpc.DirectorStub

    def __init__(self):
        """Returns a Knita client that is configured to connect back to the Knita CLI process."""
        self.__build_id = os.environ.get('KNITA_BUILD_ID')
        if self.__build_id is None:
            raise ConfigException('expected KNITA_BUILD_ID to be set')

        socket = os.environ.get('KNITA_SOCKET')
        if socket is None:
            raise ConfigException('expected KNITA_SOCKET to be set')

        channel = grpc.insecure_channel(f'unix://{socket}')
        self.__director_stub = director_pb2_grpc.DirectorStub(channel)

    def runtime(self,
                type: runtime.RuntimeType,
                tags: dict[str, str] = None,
                labels: [str] = None,
                docker_image: str = None,
                docker_pull_strategy: runtime.DockerPullStrategy = None,
                docker_basic_auth: runtime.DockerBasicAuth = None,
                docker_aws_ecr_auth: runtime.DockerAWSECRAuth = None):
        """Opens a new remote runtime configured based on options."""

        opts = executor_pb2.Opts(tags=tags, labels=labels)
        if type == runtime.RuntimeType.host:
            opts.type = executor_pb2.RuntimeType.RUNTIME_HOST
        elif type == runtime.RuntimeType.docker:
            opts.type = executor_pb2.RuntimeType.RUNTIME_DOCKER
            opts.docker.image.image_uri = docker_image
            if docker_pull_strategy is not None:
                if docker_pull_strategy == runtime.DockerPullStrategy.always:
                    opts.docker.image.pull_strategy = executor_pb2.DockerPullOpts.PULL_STRATEGY_ALWAYS
                elif docker_pull_strategy == runtime.DockerPullStrategy.never:
                    opts.docker.image.pull_strategy = executor_pb2.DockerPullOpts.PULL_STRATEGY_NEVER
                elif docker_pull_strategy == runtime.DockerPullStrategy.not_exists:
                    opts.docker.image.pull_strategy = executor_pb2.DockerPullOpts.PULL_STRATEGY_NOT_EXISTS
                else:
                    raise ConfigException(f"Unknown Docker pull strategy: {docker_pull_strategy}")
            if docker_basic_auth is not None:
                opts.docker.image.auth = executor_pb2.BasicAuth(
                    username=docker_basic_auth.username, password=docker_basic_auth.password)
            if docker_aws_ecr_auth is not None:
                opts.docker.image.auth = executor_pb2.AWSECRAuth(
                    region=docker_aws_ecr_auth.region,
                    aws_access_key_id=docker_aws_ecr_auth.aws_access_key_id,
                    aws_secret_key=docker_aws_ecr_auth.aws_secret_key)
        else:
            raise ConfigException(f"Unknown runtime type: {type}")

        req = director_pb2.OpenRequest(build_id=self.__build_id, opts=opts)
        res = self.__director_stub.Open(req)
        return runtime.Runtime(res.runtime_id, res.work_directory, res.sys_info, self.__director_stub)



from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RuntimeType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RUNTIME_UNSPECIFIED: _ClassVar[RuntimeType]
    RUNTIME_HOST: _ClassVar[RuntimeType]
    RUNTIME_DOCKER: _ClassVar[RuntimeType]
RUNTIME_UNSPECIFIED: RuntimeType
RUNTIME_HOST: RuntimeType
RUNTIME_DOCKER: RuntimeType

class ExecutorInfo(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class SystemInfo(_message.Message):
    __slots__ = ("os", "arch", "total_cpu_cores", "total_memory")
    OS_FIELD_NUMBER: _ClassVar[int]
    ARCH_FIELD_NUMBER: _ClassVar[int]
    TOTAL_CPU_CORES_FIELD_NUMBER: _ClassVar[int]
    TOTAL_MEMORY_FIELD_NUMBER: _ClassVar[int]
    os: str
    arch: str
    total_cpu_cores: int
    total_memory: int
    def __init__(self, os: _Optional[str] = ..., arch: _Optional[str] = ..., total_cpu_cores: _Optional[int] = ..., total_memory: _Optional[int] = ...) -> None: ...

class IntrospectRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IntrospectResponse(_message.Message):
    __slots__ = ("sys_info", "executor_info", "labels")
    SYS_INFO_FIELD_NUMBER: _ClassVar[int]
    EXECUTOR_INFO_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    sys_info: SystemInfo
    executor_info: ExecutorInfo
    labels: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, sys_info: _Optional[_Union[SystemInfo, _Mapping]] = ..., executor_info: _Optional[_Union[ExecutorInfo, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...

class OpenRequest(_message.Message):
    __slots__ = ("build_id", "runtime_id", "opts")
    BUILD_ID_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    build_id: str
    runtime_id: str
    opts: Opts
    def __init__(self, build_id: _Optional[str] = ..., runtime_id: _Optional[str] = ..., opts: _Optional[_Union[Opts, _Mapping]] = ...) -> None: ...

class OpenResponse(_message.Message):
    __slots__ = ("work_directory", "sys_info")
    WORK_DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    SYS_INFO_FIELD_NUMBER: _ClassVar[int]
    work_directory: str
    sys_info: SystemInfo
    def __init__(self, work_directory: _Optional[str] = ..., sys_info: _Optional[_Union[SystemInfo, _Mapping]] = ...) -> None: ...

class HeartbeatRequest(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class HeartbeatResponse(_message.Message):
    __slots__ = ("extended_by",)
    EXTENDED_BY_FIELD_NUMBER: _ClassVar[int]
    extended_by: _duration_pb2.Duration
    def __init__(self, extended_by: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class Opts(_message.Message):
    __slots__ = ("type", "labels", "tags", "host", "docker")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    DOCKER_FIELD_NUMBER: _ClassVar[int]
    type: RuntimeType
    labels: _containers.RepeatedScalarFieldContainer[str]
    tags: _containers.ScalarMap[str, str]
    host: HostOpts
    docker: DockerOpts
    def __init__(self, type: _Optional[_Union[RuntimeType, str]] = ..., labels: _Optional[_Iterable[str]] = ..., tags: _Optional[_Mapping[str, str]] = ..., host: _Optional[_Union[HostOpts, _Mapping]] = ..., docker: _Optional[_Union[DockerOpts, _Mapping]] = ...) -> None: ...

class HostOpts(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DockerOpts(_message.Message):
    __slots__ = ("image",)
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    image: DockerPullOpts
    def __init__(self, image: _Optional[_Union[DockerPullOpts, _Mapping]] = ...) -> None: ...

class DockerPullOpts(_message.Message):
    __slots__ = ("image_uri", "pull_strategy", "auth")
    class PullStrategy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PULL_STRATEGY_UNSPECIFIED: _ClassVar[DockerPullOpts.PullStrategy]
        PULL_STRATEGY_NEVER: _ClassVar[DockerPullOpts.PullStrategy]
        PULL_STRATEGY_ALWAYS: _ClassVar[DockerPullOpts.PullStrategy]
        PULL_STRATEGY_NOT_EXISTS: _ClassVar[DockerPullOpts.PullStrategy]
    PULL_STRATEGY_UNSPECIFIED: DockerPullOpts.PullStrategy
    PULL_STRATEGY_NEVER: DockerPullOpts.PullStrategy
    PULL_STRATEGY_ALWAYS: DockerPullOpts.PullStrategy
    PULL_STRATEGY_NOT_EXISTS: DockerPullOpts.PullStrategy
    IMAGE_URI_FIELD_NUMBER: _ClassVar[int]
    PULL_STRATEGY_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    image_uri: str
    pull_strategy: DockerPullOpts.PullStrategy
    auth: DockerPullAuth
    def __init__(self, image_uri: _Optional[str] = ..., pull_strategy: _Optional[_Union[DockerPullOpts.PullStrategy, str]] = ..., auth: _Optional[_Union[DockerPullAuth, _Mapping]] = ...) -> None: ...

class DockerPullAuth(_message.Message):
    __slots__ = ("basic", "aws_ecr")
    BASIC_FIELD_NUMBER: _ClassVar[int]
    AWS_ECR_FIELD_NUMBER: _ClassVar[int]
    basic: BasicAuth
    aws_ecr: AWSECRAuth
    def __init__(self, basic: _Optional[_Union[BasicAuth, _Mapping]] = ..., aws_ecr: _Optional[_Union[AWSECRAuth, _Mapping]] = ...) -> None: ...

class BasicAuth(_message.Message):
    __slots__ = ("username", "password")
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    username: str
    password: str
    def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class AWSECRAuth(_message.Message):
    __slots__ = ("region", "aws_access_key_id", "aws_secret_key")
    REGION_FIELD_NUMBER: _ClassVar[int]
    AWS_ACCESS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_SECRET_KEY_FIELD_NUMBER: _ClassVar[int]
    region: str
    aws_access_key_id: str
    aws_secret_key: str
    def __init__(self, region: _Optional[str] = ..., aws_access_key_id: _Optional[str] = ..., aws_secret_key: _Optional[str] = ...) -> None: ...

class ExecRequest(_message.Message):
    __slots__ = ("runtime_id", "exec_id", "opts")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXEC_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    exec_id: str
    opts: ExecOpts
    def __init__(self, runtime_id: _Optional[str] = ..., exec_id: _Optional[str] = ..., opts: _Optional[_Union[ExecOpts, _Mapping]] = ...) -> None: ...

class ExecOpts(_message.Message):
    __slots__ = ("name", "args", "env", "tags")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    ENV_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    name: str
    args: _containers.RepeatedScalarFieldContainer[str]
    env: _containers.RepeatedScalarFieldContainer[str]
    tags: _containers.ScalarMap[str, str]
    def __init__(self, name: _Optional[str] = ..., args: _Optional[_Iterable[str]] = ..., env: _Optional[_Iterable[str]] = ..., tags: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ExecResponse(_message.Message):
    __slots__ = ("exit_code",)
    EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
    exit_code: int
    def __init__(self, exit_code: _Optional[int] = ...) -> None: ...

class FileTransfer(_message.Message):
    __slots__ = ("runtime_id", "import_id", "file_id", "header", "body", "trailer")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    IMPORT_ID_FIELD_NUMBER: _ClassVar[int]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TRAILER_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    import_id: str
    file_id: str
    header: FileTransferHeader
    body: FileTransferBody
    trailer: FileTransferTrailer
    def __init__(self, runtime_id: _Optional[str] = ..., import_id: _Optional[str] = ..., file_id: _Optional[str] = ..., header: _Optional[_Union[FileTransferHeader, _Mapping]] = ..., body: _Optional[_Union[FileTransferBody, _Mapping]] = ..., trailer: _Optional[_Union[FileTransferTrailer, _Mapping]] = ...) -> None: ...

class FileTransferHeader(_message.Message):
    __slots__ = ("is_dir", "src_path", "dest_path", "mode", "size")
    IS_DIR_FIELD_NUMBER: _ClassVar[int]
    SRC_PATH_FIELD_NUMBER: _ClassVar[int]
    DEST_PATH_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    is_dir: bool
    src_path: str
    dest_path: str
    mode: int
    size: int
    def __init__(self, is_dir: bool = ..., src_path: _Optional[str] = ..., dest_path: _Optional[str] = ..., mode: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class FileTransferBody(_message.Message):
    __slots__ = ("offset", "data")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    data: bytes
    def __init__(self, offset: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class FileTransferTrailer(_message.Message):
    __slots__ = ("md5",)
    MD5_FIELD_NUMBER: _ClassVar[int]
    md5: bytes
    def __init__(self, md5: _Optional[bytes] = ...) -> None: ...

class ImportResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExportRequest(_message.Message):
    __slots__ = ("runtime_id", "export_id", "src_path", "dest_path")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXPORT_ID_FIELD_NUMBER: _ClassVar[int]
    SRC_PATH_FIELD_NUMBER: _ClassVar[int]
    DEST_PATH_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    export_id: str
    src_path: str
    dest_path: str
    def __init__(self, runtime_id: _Optional[str] = ..., export_id: _Optional[str] = ..., src_path: _Optional[str] = ..., dest_path: _Optional[str] = ...) -> None: ...

class CloseRequest(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class CloseResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class EventsRequest(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("build_id", "group_name", "sequence", "runtime_tender_start", "runtime_tender_end", "runtime_settlement_start", "runtime_settlement_end", "runtime_open_start", "runtime_open_end", "exec_start", "exec_end", "import_start", "import_end", "export_start", "export_end", "stdout", "stderr", "runtime_close_start", "runtime_close_end")
    BUILD_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_TENDER_START_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_TENDER_END_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_SETTLEMENT_START_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_SETTLEMENT_END_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_OPEN_START_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_OPEN_END_FIELD_NUMBER: _ClassVar[int]
    EXEC_START_FIELD_NUMBER: _ClassVar[int]
    EXEC_END_FIELD_NUMBER: _ClassVar[int]
    IMPORT_START_FIELD_NUMBER: _ClassVar[int]
    IMPORT_END_FIELD_NUMBER: _ClassVar[int]
    EXPORT_START_FIELD_NUMBER: _ClassVar[int]
    EXPORT_END_FIELD_NUMBER: _ClassVar[int]
    STDOUT_FIELD_NUMBER: _ClassVar[int]
    STDERR_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_CLOSE_START_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_CLOSE_END_FIELD_NUMBER: _ClassVar[int]
    build_id: str
    group_name: str
    sequence: int
    runtime_tender_start: RuntimeTenderStartEvent
    runtime_tender_end: RuntimeTenderEndEvent
    runtime_settlement_start: RuntimeSettlementStartEvent
    runtime_settlement_end: RuntimeSettlementEndEvent
    runtime_open_start: RuntimeOpenStartEvent
    runtime_open_end: RuntimeOpenEndEvent
    exec_start: ExecStartEvent
    exec_end: ExecEndEvent
    import_start: ImportStartEvent
    import_end: ImportEndEvent
    export_start: ExportStartEvent
    export_end: ExportEndEvent
    stdout: StdoutEvent
    stderr: StderrEvent
    runtime_close_start: RuntimeCloseStartEvent
    runtime_close_end: RuntimeCloseEndEvent
    def __init__(self, build_id: _Optional[str] = ..., group_name: _Optional[str] = ..., sequence: _Optional[int] = ..., runtime_tender_start: _Optional[_Union[RuntimeTenderStartEvent, _Mapping]] = ..., runtime_tender_end: _Optional[_Union[RuntimeTenderEndEvent, _Mapping]] = ..., runtime_settlement_start: _Optional[_Union[RuntimeSettlementStartEvent, _Mapping]] = ..., runtime_settlement_end: _Optional[_Union[RuntimeSettlementEndEvent, _Mapping]] = ..., runtime_open_start: _Optional[_Union[RuntimeOpenStartEvent, _Mapping]] = ..., runtime_open_end: _Optional[_Union[RuntimeOpenEndEvent, _Mapping]] = ..., exec_start: _Optional[_Union[ExecStartEvent, _Mapping]] = ..., exec_end: _Optional[_Union[ExecEndEvent, _Mapping]] = ..., import_start: _Optional[_Union[ImportStartEvent, _Mapping]] = ..., import_end: _Optional[_Union[ImportEndEvent, _Mapping]] = ..., export_start: _Optional[_Union[ExportStartEvent, _Mapping]] = ..., export_end: _Optional[_Union[ExportEndEvent, _Mapping]] = ..., stdout: _Optional[_Union[StdoutEvent, _Mapping]] = ..., stderr: _Optional[_Union[StderrEvent, _Mapping]] = ..., runtime_close_start: _Optional[_Union[RuntimeCloseStartEvent, _Mapping]] = ..., runtime_close_end: _Optional[_Union[RuntimeCloseEndEvent, _Mapping]] = ...) -> None: ...

class RuntimeTenderStartEvent(_message.Message):
    __slots__ = ("build_id", "tender_id", "opts")
    BUILD_ID_FIELD_NUMBER: _ClassVar[int]
    TENDER_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    build_id: str
    tender_id: str
    opts: Opts
    def __init__(self, build_id: _Optional[str] = ..., tender_id: _Optional[str] = ..., opts: _Optional[_Union[Opts, _Mapping]] = ...) -> None: ...

class RuntimeTenderEndEvent(_message.Message):
    __slots__ = ("tender_id",)
    TENDER_ID_FIELD_NUMBER: _ClassVar[int]
    tender_id: str
    def __init__(self, tender_id: _Optional[str] = ...) -> None: ...

class RuntimeSettlementStartEvent(_message.Message):
    __slots__ = ("tender_id", "contract_id", "runtime_id")
    TENDER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    tender_id: str
    contract_id: str
    runtime_id: str
    def __init__(self, tender_id: _Optional[str] = ..., contract_id: _Optional[str] = ..., runtime_id: _Optional[str] = ...) -> None: ...

class RuntimeSettlementEndEvent(_message.Message):
    __slots__ = ("tender_id", "contract_id", "runtime_id")
    TENDER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    tender_id: str
    contract_id: str
    runtime_id: str
    def __init__(self, tender_id: _Optional[str] = ..., contract_id: _Optional[str] = ..., runtime_id: _Optional[str] = ...) -> None: ...

class RuntimeOpenStartEvent(_message.Message):
    __slots__ = ("runtime_id", "opts")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    opts: Opts
    def __init__(self, runtime_id: _Optional[str] = ..., opts: _Optional[_Union[Opts, _Mapping]] = ...) -> None: ...

class RuntimeOpenEndEvent(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class RuntimeCloseStartEvent(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class RuntimeCloseEndEvent(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class StdoutEvent(_message.Message):
    __slots__ = ("data", "source")
    DATA_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    source: LogEventSource
    def __init__(self, data: _Optional[bytes] = ..., source: _Optional[_Union[LogEventSource, _Mapping]] = ...) -> None: ...

class StderrEvent(_message.Message):
    __slots__ = ("data", "source")
    DATA_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    source: LogEventSource
    def __init__(self, data: _Optional[bytes] = ..., source: _Optional[_Union[LogEventSource, _Mapping]] = ...) -> None: ...

class LogEventSource(_message.Message):
    __slots__ = ("runtime", "exec", "director")
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    EXEC_FIELD_NUMBER: _ClassVar[int]
    DIRECTOR_FIELD_NUMBER: _ClassVar[int]
    runtime: LogSourceRuntime
    exec: LogSourceExec
    director: LogSourceDirector
    def __init__(self, runtime: _Optional[_Union[LogSourceRuntime, _Mapping]] = ..., exec: _Optional[_Union[LogSourceExec, _Mapping]] = ..., director: _Optional[_Union[LogSourceDirector, _Mapping]] = ...) -> None: ...

class LogSourceRuntime(_message.Message):
    __slots__ = ("runtime_id",)
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    def __init__(self, runtime_id: _Optional[str] = ...) -> None: ...

class LogSourceExec(_message.Message):
    __slots__ = ("runtime_id", "exec_id", "system")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXEC_ID_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    exec_id: str
    system: bool
    def __init__(self, runtime_id: _Optional[str] = ..., exec_id: _Optional[str] = ..., system: bool = ...) -> None: ...

class LogSourceDirector(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExecStartEvent(_message.Message):
    __slots__ = ("runtime_id", "exec_id", "opts", "tags")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXEC_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    exec_id: str
    opts: ExecOpts
    tags: _containers.ScalarMap[str, str]
    def __init__(self, runtime_id: _Optional[str] = ..., exec_id: _Optional[str] = ..., opts: _Optional[_Union[ExecOpts, _Mapping]] = ..., tags: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ImportStartEvent(_message.Message):
    __slots__ = ("runtime_id", "import_id")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    IMPORT_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    import_id: str
    def __init__(self, runtime_id: _Optional[str] = ..., import_id: _Optional[str] = ...) -> None: ...

class ImportEndEvent(_message.Message):
    __slots__ = ("runtime_id", "import_id")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    IMPORT_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    import_id: str
    def __init__(self, runtime_id: _Optional[str] = ..., import_id: _Optional[str] = ...) -> None: ...

class ExportStartEvent(_message.Message):
    __slots__ = ("runtime_id", "export_id")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXPORT_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    export_id: str
    def __init__(self, runtime_id: _Optional[str] = ..., export_id: _Optional[str] = ...) -> None: ...

class ExportEndEvent(_message.Message):
    __slots__ = ("runtime_id", "export_id")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXPORT_ID_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    export_id: str
    def __init__(self, runtime_id: _Optional[str] = ..., export_id: _Optional[str] = ...) -> None: ...

class ExecEndEvent(_message.Message):
    __slots__ = ("runtime_id", "exec_id", "error", "exit_code")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    EXEC_ID_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    exec_id: str
    error: str
    exit_code: int
    def __init__(self, runtime_id: _Optional[str] = ..., exec_id: _Optional[str] = ..., error: _Optional[str] = ..., exit_code: _Optional[int] = ...) -> None: ...



import os
from enum import Enum

from . import director_pb2
from . import director_pb2_grpc
from . import executor_pb2


class RuntimeType(str, Enum):
    """
    An enum specifying the type of runtime to create.
    Attributes:
        host: Host is runtime that executes directly on the host executor without any containerization or virtualization.
        docker: Docker is a runtime that executes inside a Docker container.
    """
    host = 'host'
    docker = 'docker'


class DockerPullStrategy(str, Enum):
    """
    An enum specifying when to pull a Docker image during runtime creation.
    Attributes:
        always: Always ensures that a Docker pull is performed prior to starting the runtime.
        never: Never will skip the Docker pull entirely. This is useful if executors are loaded with relevant Docker
               images out of band of any individual build.
        not_exists: NotExists will run Docker pull only if no matching image is found on the executor.
    """
    always = 'always'
    never = 'never'
    not_exists = 'not-exists'


class DockerBasicAuth:
    username: str
    password: str

    def __init__(self, username: str, password: str):
        self.username = username
        self.password = password


class DockerAWSECRAuth:
    region: str
    aws_access_key_id: str
    aws_secret_key: str

    def __init__(self, region: str, aws_access_key_id: str, aws_secret_key: str):
        self.region = region
        self.aws_access_key_id = aws_access_key_id
        self.aws_secret_key = aws_secret_key


class ExecException(Exception):
    """Raised when exec finishes with a non-zero exit code."""
    exit_code: int

    def __init__(self, exit_code: int):
        self.exit_code = exit_code


class Runtime:
    """Runtime represents a local handle to a remote runtime hosted by an executor.
    """
    __runtime_id: str
    __remote_work_directory: str
    __remote_sys_info: executor_pb2.SystemInfo
    __director_stub: director_pb2_grpc.DirectorStub

    def __init__(self, runtime_id: str, remote_work_directory: str, remote_sys_info: executor_pb2.SystemInfo, director_stub: director_pb2_grpc.DirectorStub):
        self.__runtime_id = runtime_id
        self.__remote_work_directory = remote_work_directory
        self.__remote_sys_info = remote_sys_info
        self.__director_stub = director_stub

    def __enter__(self):
        return self

    def __exit__(self, *args):
        self.close()

    def id(self) -> str:
        """Returns the unique ID of the runtime."""
        return self.__runtime_id

    def sys_info(self) -> executor_pb2.SystemInfo:
        """Returns information about the runtime execution environment."""
        return self.__remote_sys_info

    def work_directory(self, rel_path: str = None) -> str:
        """Returns the fully qualified remote work directory of the runtime.
        Specify a relative path to have it joined to the work directory.
        This is helpful when exec'ing commands that reference file paths within the runtime."""
        if rel_path is None:
            return self.__remote_work_directory
        else:
            return os.path.join(self.__remote_work_directory, rel_path)

    def import_(self, src: str, dest: str = ""):
        """Import files from the local work directory into the runtime's remote work directory.
        src and dest must be relative paths. src may be a glob (doublestar syntax supported).
        If dest is empty, all files identified by src will be copied to their original location in dest."""
        req = director_pb2.ImportRequest(runtime_id=self.__runtime_id, src_path=src, dest_path=dest)
        self.__director_stub.Import(req)

    def export(self, src: str, dest: str = ""):
        """Export files from the runtime's remote work directory into the local work directory.
        src and dest must be relative paths. src may be a glob (doublestar syntax supported).
        If dest is empty, all files identified by src will be copied to their original location in dest."""
        req = director_pb2.ExportRequest(runtime_id=self.__runtime_id, src_path=src, dest_path=dest)
        self.__director_stub.Export(req)

    def exec(self, name: str, args: [str] = None, env: [str] = None, tags: dict[str, str] = None, stdout=None,
             stderr=None):
        """Exec executes a command inside the remote runtime.
        Check the returned ExecResponse to see the command's exit code (a non-zero code is not an exception)."""
        req = director_pb2.ExecRequest(runtime_id=self.__runtime_id,
                                       opts=executor_pb2.ExecOpts(name=name, args=args, env=env, tags=tags))
        for event in self.__director_stub.Exec(req):
            field = event.WhichOneof('payload')
            payload = getattr(event, field)
            if field == 'exec_end':
                if payload.exit_code is not 0:
                    raise ExecException(payload.exit_code)
                return
            elif field == 'stdout':
                if stdout is not None:
                    stdout.write(payload.data.decode())
            elif field == 'stderr':
                if stderr is not None:
                    stderr.write(payload.data.decode())

    def close(self):
        """Close the runtime. After a call to close the runtime can no longer be used."""
        req = executor_pb2.CloseRequest(runtime_id=self.__runtime_id)
        self.__director_stub.Close(req)



from .client import Client
from .runtime import RuntimeType, DockerPullStrategy, DockerBasicAuth, DockerAWSECRAuth

__all__ = ['Client', 'RuntimeType', 'DockerPullStrategy', 'DockerBasicAuth', 'DockerAWSECRAuth']



from . import executor_pb2 as _executor_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OpenRequest(_message.Message):
    __slots__ = ("build_id", "opts")
    BUILD_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    build_id: str
    opts: _executor_pb2.Opts
    def __init__(self, build_id: _Optional[str] = ..., opts: _Optional[_Union[_executor_pb2.Opts, _Mapping]] = ...) -> None: ...

class OpenResponse(_message.Message):
    __slots__ = ("runtime_id", "work_directory", "sys_info")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    WORK_DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    SYS_INFO_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    work_directory: str
    sys_info: _executor_pb2.SystemInfo
    def __init__(self, runtime_id: _Optional[str] = ..., work_directory: _Optional[str] = ..., sys_info: _Optional[_Union[_executor_pb2.SystemInfo, _Mapping]] = ...) -> None: ...

class ImportRequest(_message.Message):
    __slots__ = ("runtime_id", "src_path", "dest_path")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    SRC_PATH_FIELD_NUMBER: _ClassVar[int]
    DEST_PATH_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    src_path: str
    dest_path: str
    def __init__(self, runtime_id: _Optional[str] = ..., src_path: _Optional[str] = ..., dest_path: _Optional[str] = ...) -> None: ...

class ImportResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExportRequest(_message.Message):
    __slots__ = ("runtime_id", "src_path", "dest_path")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    SRC_PATH_FIELD_NUMBER: _ClassVar[int]
    DEST_PATH_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    src_path: str
    dest_path: str
    def __init__(self, runtime_id: _Optional[str] = ..., src_path: _Optional[str] = ..., dest_path: _Optional[str] = ...) -> None: ...

class ExportResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class EventsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExecRequest(_message.Message):
    __slots__ = ("runtime_id", "opts")
    RUNTIME_ID_FIELD_NUMBER: _ClassVar[int]
    OPTS_FIELD_NUMBER: _ClassVar[int]
    runtime_id: str
    opts: _executor_pb2.ExecOpts
    def __init__(self, runtime_id: _Optional[str] = ..., opts: _Optional[_Union[_executor_pb2.ExecOpts, _Mapping]] = ...) -> None: ...

class ExecEvent(_message.Message):
    __slots__ = ("exec_start", "exec_end", "stdout", "stderr")
    EXEC_START_FIELD_NUMBER: _ClassVar[int]
    EXEC_END_FIELD_NUMBER: _ClassVar[int]
    STDOUT_FIELD_NUMBER: _ClassVar[int]
    STDERR_FIELD_NUMBER: _ClassVar[int]
    exec_start: ExecStartEvent
    exec_end: ExecEndEvent
    stdout: ExecStdoutEvent
    stderr: ExecStderrEvent
    def __init__(self, exec_start: _Optional[_Union[ExecStartEvent, _Mapping]] = ..., exec_end: _Optional[_Union[ExecEndEvent, _Mapping]] = ..., stdout: _Optional[_Union[ExecStdoutEvent, _Mapping]] = ..., stderr: _Optional[_Union[ExecStderrEvent, _Mapping]] = ...) -> None: ...

class ExecStartEvent(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExecEndEvent(_message.Message):
    __slots__ = ("error", "exit_code")
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
    error: str
    exit_code: int
    def __init__(self, error: _Optional[str] = ..., exit_code: _Optional[int] = ...) -> None: ...

class ExecStdoutEvent(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class ExecStderrEvent(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import executor_pb2 as executor_dot_v1_dot_executor__pb2

GRPC_GENERATED_VERSION = '1.63.0'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in executor/v1/executor_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ExecutorStub(object):
    """TODO split into executor and runtime services?
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Introspect = channel.unary_unary(
                '/executor.Executor/Introspect',
                request_serializer=executor_dot_v1_dot_executor__pb2.IntrospectRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.IntrospectResponse.FromString,
                _registered_method=True)
        self.Open = channel.unary_unary(
                '/executor.Executor/Open',
                request_serializer=executor_dot_v1_dot_executor__pb2.OpenRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.OpenResponse.FromString,
                _registered_method=True)
        self.Heartbeat = channel.unary_unary(
                '/executor.Executor/Heartbeat',
                request_serializer=executor_dot_v1_dot_executor__pb2.HeartbeatRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.HeartbeatResponse.FromString,
                _registered_method=True)
        self.Exec = channel.unary_unary(
                '/executor.Executor/Exec',
                request_serializer=executor_dot_v1_dot_executor__pb2.ExecRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.ExecResponse.FromString,
                _registered_method=True)
        self.Import = channel.stream_unary(
                '/executor.Executor/Import',
                request_serializer=executor_dot_v1_dot_executor__pb2.FileTransfer.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.ImportResponse.FromString,
                _registered_method=True)
        self.Export = channel.unary_stream(
                '/executor.Executor/Export',
                request_serializer=executor_dot_v1_dot_executor__pb2.ExportRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.FileTransfer.FromString,
                _registered_method=True)
        self.Close = channel.unary_unary(
                '/executor.Executor/Close',
                request_serializer=executor_dot_v1_dot_executor__pb2.CloseRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.CloseResponse.FromString,
                _registered_method=True)
        self.Events = channel.unary_stream(
                '/executor.Executor/Events',
                request_serializer=executor_dot_v1_dot_executor__pb2.EventsRequest.SerializeToString,
                response_deserializer=executor_dot_v1_dot_executor__pb2.Event.FromString,
                _registered_method=True)


class ExecutorServicer(object):
    """TODO split into executor and runtime services?
    """

    def Introspect(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Open(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Heartbeat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exec(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Import(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Export(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Events(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExecutorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Introspect': grpc.unary_unary_rpc_method_handler(
                    servicer.Introspect,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.IntrospectRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.IntrospectResponse.SerializeToString,
            ),
            'Open': grpc.unary_unary_rpc_method_handler(
                    servicer.Open,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.OpenRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.OpenResponse.SerializeToString,
            ),
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.HeartbeatRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.HeartbeatResponse.SerializeToString,
            ),
            'Exec': grpc.unary_unary_rpc_method_handler(
                    servicer.Exec,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.ExecRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.ExecResponse.SerializeToString,
            ),
            'Import': grpc.stream_unary_rpc_method_handler(
                    servicer.Import,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.FileTransfer.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.ImportResponse.SerializeToString,
            ),
            'Export': grpc.unary_stream_rpc_method_handler(
                    servicer.Export,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.ExportRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.FileTransfer.SerializeToString,
            ),
            'Close': grpc.unary_unary_rpc_method_handler(
                    servicer.Close,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.CloseRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.CloseResponse.SerializeToString,
            ),
            'Events': grpc.unary_stream_rpc_method_handler(
                    servicer.Events,
                    request_deserializer=executor_dot_v1_dot_executor__pb2.EventsRequest.FromString,
                    response_serializer=executor_dot_v1_dot_executor__pb2.Event.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'executor.Executor', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Executor(object):
    """TODO split into executor and runtime services?
    """

    @staticmethod
    def Introspect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/executor.Executor/Introspect',
            executor_dot_v1_dot_executor__pb2.IntrospectRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.IntrospectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Open(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/executor.Executor/Open',
            executor_dot_v1_dot_executor__pb2.OpenRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.OpenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/executor.Executor/Heartbeat',
            executor_dot_v1_dot_executor__pb2.HeartbeatRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.HeartbeatResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Exec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/executor.Executor/Exec',
            executor_dot_v1_dot_executor__pb2.ExecRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.ExecResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Import(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/executor.Executor/Import',
            executor_dot_v1_dot_executor__pb2.FileTransfer.SerializeToString,
            executor_dot_v1_dot_executor__pb2.ImportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Export(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/executor.Executor/Export',
            executor_dot_v1_dot_executor__pb2.ExportRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.FileTransfer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Close(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/executor.Executor/Close',
            executor_dot_v1_dot_executor__pb2.CloseRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.CloseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Events(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/executor.Executor/Events',
            executor_dot_v1_dot_executor__pb2.EventsRequest.SerializeToString,
            executor_dot_v1_dot_executor__pb2.Event.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
